@@ -7,7 +7,7 @@ class Plugin(plugins.BasePlugin):
     __name__ = 'mailq'
     def run(self, *unused):
         import os
-        stream = os.popen("mailq | /usr/bin/tail -n1 | /usr/bin/gawk '{print $5}'")
+        stream = os.popen("sudo /usr/bin/mailq | /usr/bin/tail -n1 | /usr/bin/gawk '{print $5}'")
         retval = stream.read()
         results = {}
         if len(retval) == 1:
